==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Input/flac/translations/flac_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="58"/>
        <source>FLAC Plugin</source>
        <translation>FLAC Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="60"/>
        <source>FLAC Files</source>
        <translation>FLAC Dosyaları</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="191"/>
        <source>About FLAC Audio Plugin</source>
        <translation>FLAC Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="192"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="193"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="89"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="91"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/flac/translations/flac_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Plugin</source>
        <translation>FLAC Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="55"/>
        <source>FLAC Files</source>
        <translation>FLAC Dosyaları</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="186"/>
        <source>About FLAC Audio Plugin</source>
        <translation>FLAC Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="187"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="188"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="89"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="91"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>
